[gimp] Bug 687070 - Modifier+Space doesn't work as shortcut



commit 99dfc5930f1bf00b50067d6d02c408515bebd35a
Author: Michael Natterer <mitch gimp org>
Date:   Sun Oct 28 23:33:31 2012 +0100

    Bug 687070 - Modifier+Space doesn't work as shortcut
    
    Don't allow to assign Modifier+Space shortcuts, there is so much code
    dealing with Space in canvas event handling, we can't have it invoke
    arbitrary actions at the same time.

 app/widgets/gimpactionview.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/app/widgets/gimpactionview.c b/app/widgets/gimpactionview.c
index f64a11f..5af0387 100644
--- a/app/widgets/gimpactionview.c
+++ b/app/widgets/gimpactionview.c
@@ -764,12 +764,14 @@ gimp_action_view_accel_edited (GtkCellRendererAccel *accel,
   if (! accel_key ||
 
       /* Don't allow arrow keys, they are all swallowed by the canvas
        * and cannot be invoked anyway
        */
       accel_key == GDK_KEY_Left  ||
       accel_key == GDK_KEY_Right ||
       accel_key == GDK_KEY_Up    ||
-      accel_key == GDK_KEY_Down)
+      accel_key == GDK_KEY_Down  ||
+      accel_key == GDK_KEY_space ||
+      accel_key == GDK_KEY_KP_Space)
     {
       gimp_message_literal (view->manager->gimp,
 			    G_OBJECT (view), GIMP_MESSAGE_ERROR,
@@ -764,12 +764,14 @@ gimp_action_view_accel_edited (GtkCellRendererAccel *accel,
 
       /* Don't allow arrow keys, they are all swallowed by the canvas
-       * and cannot be invoked anyway
+       * and cannot be invoked anyway, the same applies to space.
        */
       accel_key == GDK_KEY_Left  ||



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]